from enum import Enum
from typing import Optional

from pydantic import BaseModel, Field


class BCDProtectionRequirements(Enum):
    """
    BCD Firewall Protection Requirements
    """
    LEVEL_1 = 1
    LEVEL_2 = 2
    SPECIAL = 10


class BCDSystemType(Enum):
    CLIENT = 1
    SERVER = 2
    PRINTER = 3
    IOT_DEVICES = 4
    VPN_WIFI_ONLY = 5
    OTHER = 6


class IPAddressVersion(Enum):
    IPV6_ONLY = 1
    DUAL_STACK = 2


class BCDRequestModel(BaseModel):
    oe: str = Field()
    group: str = Field()
    protection_requirement: BCDProtectionRequirements = Field()
    protection_requirement_note: Optional[str] = Field(default=None)
    type_of_system: BCDSystemType = Field()
    type_of_system_note: Optional[str] = Field(default=None)
    load_balancer: bool = Field()
    bcd_name: str = Field()
    access_to_internet: bool = Field()
    access_from_internet: bool = Field()
    access_from_internet_explanation: Optional[str] = Field(default=None)
    type_of_subnet: IPAddressVersion = Field()
    ipv4_subnet_size: int = Field()
    ipv4_subnet_size_explanation: Optional[str] = Field(default=None)
    dhcp: bool = Field()
    dhcp_pool: bool = Field()
    dhcp_pool_size: int = Field()
    own_dhcp_server: bool = Field()
    location_cs: bool = Field()
    location_cn: bool = Field()
    location_vm_cluster_unknown: bool = Field()
    location_vm_cluster_cs: bool = Field()
    location_vm_cluster_cn: bool = Field()
    location_scc_server_room_cs: bool = Field()
    location_scc_server_room_cn: bool = Field()
    location_vpn_wifi_to_vlan: bool = Field()
    vpn2vlan: bool = Field()
    wifi2vlan: bool = Field()
    additional_comments: Optional[str] = Field(default=None)
